% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/lsm_l_shdi.R
\name{lsm_l_shdi}
\alias{lsm_l_shdi}
\title{SHDI (landscape level)}
\usage{
lsm_l_shdi(landscape)
}
\arguments{
\item{landscape}{A categorical raster object: SpatRaster; Raster* Layer, Stack, Brick; stars or a list of SpatRasters.}
}
\value{
tibble
}
\description{
Shannon's diversity index (Diversity metric)
}
\details{
\deqn{SHDI = - \sum \limits_{i = 1}^{m} (P_{i} * \ln P_{i})}
where \eqn{P_{i}} is the proportion of class i.

SHDI is a 'Diversity metric'. It is a widely used metric in biodiversity and ecology
and takes both the number of classes and the abundance of each class into account.

\subsection{Units}{None}
\subsection{Range}{SHDI >= 0}
\subsection{Behaviour}{Equals SHDI = 0 when only one patch is present and increases,
without limit, as the number of classes increases while the proportions are
equally distributed}
}
\examples{
landscape <- terra::rast(landscapemetrics::landscape)
lsm_l_shdi(landscape)

}
\references{
McGarigal K., SA Cushman, and E Ene. 2023. FRAGSTATS v4: Spatial Pattern Analysis
Program for Categorical Maps. Computer software program produced by the authors;
available at the following web site: https://www.fragstats.org

Shannon, C., and W. Weaver. 1949. The mathematical theory of
communication. Univ. IllinoisPress, Urbana
}
\seealso{
\code{\link{lsm_c_pland}}
}
