% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/lsm_p_contig.R
\name{lsm_p_contig}
\alias{lsm_p_contig}
\title{CONTIG (patch level)}
\usage{
lsm_p_contig(landscape, directions = 8)
}
\arguments{
\item{landscape}{A categorical raster object: SpatRaster; Raster* Layer, Stack, Brick; stars or a list of SpatRasters.}

\item{directions}{The number of directions in which patches should be
connected: 4 (rook's case) or 8 (queen's case).}
}
\value{
tibble
}
\description{
Contiguity index (Shape metric)
}
\details{
\deqn{CONTIG =  \frac{\Bigg[\frac{\sum\limits_{r=1}^z  c_{ijr}}{a_{ij}}\Bigg] - 1 }{ v - 1} }

where \eqn{c_{ijr}} is the contiguity value for pixel r in patch ij,
\eqn{a_{ij}} the area of the respective patch (number of cells) and \eqn{v} is
the size of the filter matrix (13 in this case).

CONTIG is a 'Shape metric'. It asses the spatial connectedness (contiguity) of
cells in patches. CONTIG coerces patch values to a value of 1 and the background
to NA. A nine cell focal filter matrix:

\if{html}{\out{<div class="sourceCode">}}\preformatted{filter_matrix <- matrix(c(1, 2, 1,
                          2, 1, 2,
                          1, 2, 1), 3, 3, byrow = T)
}\if{html}{\out{</div>}}

... is then used to weight orthogonally contiguous pixels more heavily than
diagonally contiguous pixels. Therefore, larger and more connections between
patch cells in the rookie case result in larger contiguity index values.

\subsection{Units}{None}
\subsection{Range}{0 >= CONTIG <= 1}
\subsection{Behaviour}{Equals 0 for one-pixel patches and increases to a limit
of 1 (fully connected patch).}
}
\examples{
landscape <- terra::rast(landscapemetrics::landscape)
lsm_p_contig(landscape)

}
\references{
McGarigal K., SA Cushman, and E Ene. 2023. FRAGSTATS v4: Spatial Pattern Analysis
Program for Categorical Maps. Computer software program produced by the authors;
available at the following web site: https://www.fragstats.org

LaGro, J. 1991. Assessing patch shape in landscape mosaics.
Photogrammetric Engineering and Remote Sensing, 57(3), 285-293
}
\seealso{
\code{\link{lsm_c_contig_mn}},
\code{\link{lsm_c_contig_sd}},
\code{\link{lsm_c_contig_cv}}, \cr
\code{\link{lsm_l_contig_mn}},
\code{\link{lsm_l_contig_sd}},
\code{\link{lsm_l_contig_cv}}
}
